<?php

namespace Bixo\Opportunity\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Opportunity\Actions\OpportunityAction;
use Bixo\Opportunity\Http\Requests\OpportunityActionRequest;
use Bixo\Opportunity\Http\Resources\OpportunityResource;
use Bixo\Opportunity\Models\Opportunity;

/**
 * Admin web controller class.
 */
class OpportunityActionController extends BaseController
{

    /**
     * Action controller function for opportunity.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OpportunityActionRequest $request, Opportunity $opportunity, $action)
    {
        try {
            $request = $request->all();
            $opportunity = OpportunityAction::run($action, $opportunity, $request);

            $data = new OpportunityResource($opportunity);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('opportunity::opportunity.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('opportunity/opportunity/' . $opportunity->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('opportunity/opportunity/' . $opportunity->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
