<?php

namespace Bixo\Opportunity\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Opportunity\Actions\ViewingAction;
use Bixo\Opportunity\Http\Requests\ViewingActionRequest;
use Bixo\Opportunity\Http\Resources\ViewingResource;
use Bixo\Opportunity\Models\Viewing;

/**
 * Admin web controller class.
 */
class ViewingActionController extends BaseController
{

    /**
     * Action controller function for viewing.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ViewingActionRequest $request, Viewing $viewing, $action)
    {
        try {
            $request = $request->all();
            $viewing = ViewingAction::run($action, $viewing, $request);

            $data = new ViewingResource($viewing);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('opportunity::viewing.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('opportunity/viewing/' . $viewing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('opportunity/viewing/' . $viewing->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
