<?php

namespace Bixo\Opportunity\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;

class OfferResource extends JsonResource
{

    public function itemLink()
    {
        return guard_url('opportunity/offer') . '/' . $this->getRouteKey();
    }

    public function title()
    {
        if ($this->title != '') {
            return $this->title;
        }

        if ($this->name != '') {
            return $this->name;
        }

        return 'None';
    }

    public function toArray($request)
    {
        return [
            'id' => $this->getRouteKey(),
            'title' => $this->title(),
            'slug' => $this->slug,
            'ref' => $this->ref,
            'opportunity_id' => $this->opportunity_id,
            'customer_by' => $this->customer_by,
            'property_by' => $this->property_by,
            'property_id' => $this->property_id,
            'viewing_id' => $this->viewing_id,
            'status' => $this->status,
            'priority' => $this->priority,
            'date_time' => $this->date_time,
            'price' => $this->price,
            'cheques' => $this->cheques,
            'frequency' => $this->frequency,
            'feedbacks' => $this->feedbacks,
            'property_type' => $this->property_type,
            'category_type' => $this->category_type,
            'category' => $this->category,
            'beds' => $this->beds,
            'region_id' => $this->region_id,
            'location_id' => $this->location_id,
            'sublocation_id' => $this->sublocation_id,
            'building_id' => $this->building_id,
            'listing_price' => $this->listing_price,
            'baths' => $this->baths,
            'bua' => $this->bua,
            'furnished' => $this->furnished,
            'view' => $this->view,
            'parking' => $this->parking,
            'unit' => $this->unit,
            'notification' => $this->notification,
            'user_id' => $this->user_id,
            'user_type' => $this->user_type,
            'created_at' => !is_null($this->created_at) ? $this->created_at->format('Y-m-d H:i:s') : null,
            'updated_at' => !is_null($this->updated_at) ? $this->updated_at->format('Y-m-d H:i:s') : null,
            'meta' => [
                'exists' => $this->exists(),
                'link' => $this->itemLink(),
                'upload_url' => $this->getUploadURL(''),
                'workflow' => $this->workflows(),
                'actions' => $this->actions(),
            ],
        ];
    }

    /**
     * Get additional data that should be returned with the resource array.
     *
     * @param     \Illuminate\Http\Request  $request
     * @return array
     */
    public function with($request)
    {
        return [
            'meta' => [
                'exists' => $this->exists(),
                'link' => $this->itemLink(),
                'upload_url' => $this->getUploadURL(''),
                'workflow' => $this->workflows(),
                'actions' => $this->actions(),
            ],
        ];
    }

    /**
     * Get the workflows for the resource.
     *
     * @return array
     */
    private function workflows()
    {
        $arr = [];
                $workflow = $this->resource->workflow();
        foreach ($workflow->transitions($this) as $key => $transition) {
            $name = $transition->getName();
            $arr[$key]['url'] = guard_url('opportunity/offer/workflow/' . $this->getRouteKey() . '/' . $name);
            $arr[$key]['name'] = $name;
            $arr[$key]['key'] = $name;
            $arr[$key]['form'] = $workflow->form($transition);
            $arr[$key]['label'] = trans('opportunity::offer.workflow.' . $name);
        }
                return $arr;

    }
    
    /**
     * Get the actions for the resource.
     *
     * @return array
     */
    private function actions()
    {

        $arr = [];
                $actions = $this->resource->actions()->details();
        foreach ($actions as $key => $action) {
            $name = $action->name();
            $arr[$key]['url'] = guard_url('opportunity/offer//action' . $this->getRouteKey() . '/' . $action->name());
            $arr[$key]['name'] = $name;
            $arr[$key]['key'] = $name;
            $arr[$key]['form'] = $action->form();
            $arr[$key]['label'] = trans('opportunity::offer.actions.' . $name);
        }
        
        return $arr;
    }
}
