<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\OfferWorkflow as OfferWorkflowEvent;
use Bixo\Opportunity\Notifications\OfferWorkflow as OfferWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class OfferWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(OfferWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $offer is submitted.
     *
     * @param OfferWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(OfferWorkflowEvent $event)
    {
        $client = $event->offer->client;
        Notification::send($client, new OfferWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $offer is published.
     *
     * @param OfferWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(OfferWorkflowEvent $event)
    {
        $client = $event->offer->client;
        Notification::send($client, new OfferWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $offer is approved.
     *
     * @param OfferWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(OfferWorkflowEvent $event)
    {
        $client = $event->offer->client;
        Notification::send($client, new OfferWorkflowNotification($event));
    }

    /**
     * Handles the $offer workflow event as a listener.
     *
     * @param OfferWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(OfferWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
