<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\OpportunityAction as OpportunityActionEvent;
use Bixo\Opportunity\Notifications\OpportunityAction as OpportunityActionNotification;
use Litepie\Actions\Concerns\AsAction;

class OpportunityAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the OpportunityActionEvent.
     *
     * @param   OpportunityActionEvent  $event
     * @return mixed
     */
    public function handle(OpportunityActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $opportunity.
     *
     * @param   OpportunityActionEvent  $event
     * @return void
     */
    public function create(OpportunityActionEvent $event)
    {
        $client = $event->opportunity->client;
        Notification::send($client, new OpportunityActionNotification($event));
    }

    /**
     * Handle the OpportunityActionEvent as a listener.
     *
     * @param   OpportunityActionEvent  $event
     * @return mixed
     */
    public function asListener(OpportunityActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   OpportunityActionEvent  $event
     * @return bool
     */
    private function isAllowed(OpportunityActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
