<?php
namespace Bixo\Opportunity\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Opportunity\Events\OfferAction as OfferActionEvent;
use Bixo\Opportunity\Models\Offer;

class OfferAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $offer;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param OfferActionEvent $offer
     */
    public function __construct(OfferActionEvent $offer)
    {
        $this->action = $event->action;
        $this->offer = $offer;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Offer Approved - ' . config('app.name'))
            ->view('opportunity::offer.email.action', ['data' => $this->offer]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
