<?php
namespace Bixo\Opportunity\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Opportunity\Events\OpportunityAction as OpportunityActionEvent;
use Bixo\Opportunity\Models\Opportunity;

class OpportunityAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $opportunity;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param OpportunityActionEvent $opportunity
     */
    public function __construct(OpportunityActionEvent $opportunity)
    {
        $this->action = $event->action;
        $this->opportunity = $opportunity;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Opportunity Approved - ' . config('app.name'))
            ->view('opportunity::opportunity.email.action', ['data' => $this->opportunity]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
