<?php

namespace Bixo\Opportunity\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Opportunity\Opportunities;

class OpportunityServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'opportunity');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'opportunity');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\Opportunity\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Opportunity\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Opportunity\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Opportunity\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.opportunity', function($app)
        {
            return $this->app->make(Opportunity::class);
        });
    }

    /**
     * Merges user's and opportunity's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.opportunity'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/opportunity.php', 'bixo.opportunity.opportunity'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/offer.php', 'bixo.opportunity.offer'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/preferance.php', 'bixo.opportunity.preferance'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/viewing.php', 'bixo.opportunity.viewing'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.opportunity'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/opportunity')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/opportunity')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/opportunity')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
