<?php

namespace Bixo\Opportunity\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Bixo\Opportunity\Models\Opportunity;
use Bixo\Opportunity\Models\Offer;
use Bixo\Opportunity\Models\Preferance;
use Bixo\Opportunity\Models\Viewing;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Opportunity\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/opportunity/opportunity/*')) {
            Route::bind('opportunity', function ($opportunity) {
                return Opportunity::findorNew($opportunity);
            });
        }
        if (Request::is('*/opportunity/offer/*')) {
            Route::bind('offer', function ($offer) {
                return Offer::findorNew($offer);
            });
        }
        if (Request::is('*/opportunity/preferance/*')) {
            Route::bind('preferance', function ($preferance) {
                return Preferance::findorNew($preferance);
            });
        }
        if (Request::is('*/opportunity/viewing/*')) {
            Route::bind('viewing', function ($viewing) {
                return Viewing::findorNew($viewing);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
